@@ -13,7 +13,6 @@ export.sc_power <- function(object, caption = NA, footnote = NA, filename = NA,
     #B <- object$design[object$phases.B]
     caption <- c("Test power in percent")#, .phases_string(A, B))
   }
-  kable_options$caption <- caption
   
   if (is.na(footnote)) {
     #footnote <- paste(
@@ -32,16 +31,16 @@ export.sc_power <- function(object, caption = NA, footnote = NA, filename = NA,
   #out$p <- .nice_p(out$p)
   
   
-  kable_options$x <- out
-  kable_options$align <- c("l", rep("r", ncol(out) - 1))
-  table <- do.call(kable, kable_options)
-  kable_styling_options$kable_input <- table
-  table <- do.call(kable_styling, kable_styling_options)
-  if (!is.na(footnote) && footnote != "") 
-    table <- footnote(table, general = footnote, threeparttable = TRUE)
+  table <- .create_table(
+    out, 
+    kable_options, 
+    kable_styling_options, 
+    caption = caption,
+    footnote = footnote
+  )
   
   # finish ------------------------------------------------------------------
   
-  if (!is.na(filename)) cat(table, file = filename)
+  if (!is.na(filename)) .save_export(table, filename)
   table
-}
\ No newline at end of file
+}
