@@ -1,4 +1,6 @@
-#' @rdname export
+#' @describeIn tau_u Export results as html table
+#' @order 3
+#' @inheritParams export
 #' @param meta If TRUE, the results of the meta analysis will be exported. If
 #'   FALSE, each single-case is exported.
 #' @param select Character vector with name of variables to be included. When
@@ -26,8 +28,7 @@ export.sc_tauu <- function(object,
       caption <- "Tau-U analyses"
     #, .phases_string(A, B))
   }
-  kable_options$caption <- caption
-  
+
   if (is.na(footnote)) {
     footnote <- paste(
       "Method is '", object$method, 
@@ -53,6 +54,7 @@ export.sc_tauu <- function(object,
     Model <- rep(names_models, length = nrow(out)) 
     Case <- lapply(names(tables), function(x) c(x, rep(" ", 6))) |> unlist()
     out <- cbind(Case, Model, out)
+    kable_options$align <- c("l", "l", rep("c", ncol(out) - 2))
     
   }  
   
@@ -70,22 +72,22 @@ export.sc_tauu <- function(object,
   
   opts <- options(knitr.kable.NA = "")
   
-  kable_options$x <- out
-  kable_options$align <- c("l", rep("r", ncol(out) - 1))
-  table <- do.call(kable, kable_options)
-  kable_styling_options$kable_input <- table
-  table <- do.call(kable_styling, kable_styling_options)
+  table <- .create_table(
+    out, 
+    kable_options, 
+    kable_styling_options, 
+    caption = caption,
+    footnote = footnote
+  )
   
   #if (!meta) {
   #  table <- add_indent(table, (1:nrow(out))[-(1:(nrow(out)/7) * 7 - 6)])
   #}
   
-  if (!is.na(footnote) && footnote != "") 
-    table <- footnote(table, general = footnote, threeparttable = TRUE)
   
   options(opts)
   # finish ------------------------------------------------------------------
   
-  if (!is.na(filename)) cat(table, file = filename)
+  if (!is.na(filename)) .save_export(table, filename)
   table
 }
